G  L  I  A
==========
|glia-logo|

Offical Desktop Client for Glial Engines

|travis| |appveyor| |code-climate| |codecov| |docs|

.. |glia-logo| image:: https://i.imgur.com/LiSEGjE.png
   :width: 127px
.. |travis| image:: https://travis-ci.com/GliaHQ/Glia.svg?branch=master
    :target: https://travis-ci.com/GliaHQ/Glia
.. |appveyor| image:: https://ci.appveyor.com/api/projects/status/yo5fg44wpkf9rk4w?svg=true
  :target: https://ci.appveyor.com/project/daegontaven/glia
.. |code-climate| image:: https://api.codeclimate.com/v1/badges/3a7bc7e815dbac6d01d3/maintainability
   :target: https://codeclimate.com/github/GliaHQ/Glia/maintainability
   :alt: Maintainability
.. |codecov| image:: https://codecov.io/gh/GliaHQ/Glia/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/GliaHQ/Glia
.. |docs| image:: https://readthedocs.org/projects/glia-docs/badge/?version=latest
  :target: https://glia-docs.readthedocs.io/en/latest/?badge=latest
  :alt: Documentation Status
